import {Component, OnInit} from "@angular/core";
import {properties} from "../../../../environments/environment";
import {Router} from "@angular/router";
import {Meta, Title} from "@angular/platform-browser";
import {SEOService} from "../../sharedComponents/SEO/SEO.service";

@Component({
  selector: 'indicator-themes-page',
  template: `
		<div class="uk-section">
			<div class="uk-container uk-container-large">
				<h1>Indicator Themes<span class="uk-text-primary">.</span></h1>
			</div>
			<div class="uk-section uk-container uk-container-large">
				<div class="uk-grid uk-grid-large uk-flex-middle" uk-grid>
					<div class="uk-width-3-5@m">
					<img src="assets/common-assets/monitor-assets/indicator-themes-circle.png">
					</div>
					<div class="uk-width-2-5@m">
						<div class="uk-width-4-5@m">
							<h5>Indicator themes that we are covering in the Monitor dashboards.</h5>
							<div class="uk-margin-bottom">
								Please be aware that this is the current set, which will be enriched as requests and data are coming into the <a href="">OpenAIRE Research Graph</a>. We are in your disposal to add more indicator themes that may fit your needs.
							</div>
							<div>
								Check out the indicator pages (for funders, institutions and research initiatives put hyperlinks for each) for the specific indicators for each type of dashboard, and the  <a href="">methodology and terminology</a> page ( hyperlink to terminology) on how we produce the metrics.
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
  `
})
export class IndicatorThemesComponent implements OnInit {
  public properties = properties;
  
  constructor(private router: Router,
              private meta: Meta,
              private title: Title,
              private seoService: SEOService) {
  }
  
  ngOnInit() {
    const description = "Monitor | Indicator Themes";
		const title = "Monitor | Indicator Themes";
		this.metaTags(title, description);
  }
  
  metaTags(title, description) {
    const url = properties.domain + properties.baseLink + this.router.url;
    this.seoService.createLinkForCanonicalURL(url, false);
    this.meta.updateTag({content: url}, "property='og:url'");
    this.meta.updateTag({content: description}, "name='description'");
    this.meta.updateTag({content: description}, "property='og:description'");
    this.meta.updateTag({content: title}, "property='og:title'");
    this.title.setTitle(title);
  }
}
